@@ -1,4 +1,4 @@
-//@line 40 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 40 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -20,6 +20,22 @@ function LOG(str) {
     dump("*** Feeds: " + str + "\n");
 }
 
+/**
+ * Wrapper function for nsIIOService::newURI.
+ * @param aURLSpec
+ *        The URL string from which to create an nsIURI.
+ * @returns an nsIURI object, or null if the creation of the URI failed.
+ */
+function makeURI(aURLSpec, aCharset) {
+  var ios = Cc["@mozilla.org/network/io-service;1"].
+            getService(Ci.nsIIOService);
+  try {
+    return ios.newURI(aURLSpec, aCharset, null);
+  } catch (ex) { }
+
+  return null;
+}
+
 const XML_NS = "http://www.w3.org/XML/1998/namespace"
 const HTML_NS = "http://www.w3.org/1999/xhtml";
 const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
@@ -40,6 +56,8 @@ const FW_CONTRACTID = "@mozilla.org/browser/feeds/result-writer;1";
 const TITLE_ID = "feedTitleText";
 const SUBTITLE_ID = "feedSubtitleText";
 
+const ICON_DATAURL_PREFIX = "data:image/x-icon;base64,";
+
 function FeedWriter() {
 }
 FeedWriter.prototype = {
@@ -146,7 +164,7 @@ FeedWriter.prototype = {
     return this._selectedApplicationItemWrapped;
   },
 
-//@line 201 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 219 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
   /**
    * Writes the feed title into the preview document.
@@ -271,11 +289,7 @@ FeedWriter.prototype = {
     var feedService = 
         Cc["@mozilla.org/browser/feeds/result-service;1"].
         getService(Ci.nsIFeedResultService);
-        
-    var ios = 
-        Cc["@mozilla.org/network/io-service;1"].
-        getService(Ci.nsIIOService);
- 
+
     try {
       var result = 
         feedService.getFeedResult(this._getOriginalURI(this._window));
@@ -312,7 +326,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 384 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 398 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
     var ios = 
         Cc["@mozilla.org/network/io-service;1"].
         getService(Ci.nsIIOService);
@@ -373,9 +387,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 450 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 464 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 453 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 467 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             var selectedAppMenuItem = this.selectedApplicationItemWrapped;
             this._initMenuItemWithFile(selectedAppMenuItem, selectedApp);
 
@@ -512,7 +526,7 @@ FeedWriter.prototype = {
             selectedAppMenuItem.hidden = false;
             selectedAppMenuItem.doCommand();
 
-//@line 598 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 612 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
             break;
           }
         }
@@ -562,7 +576,7 @@ FeedWriter.prototype = {
       selectedApplicationItem.hidden = true;
     }
 
-//@line 693 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 707 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
 
     // "Choose Application..." menuitem
     menuItem = this._document.createElementNS(XUL_NS, "menuitem");
@@ -588,8 +602,6 @@ FeedWriter.prototype = {
       getService(Ci.nsIWebContentConverterService);
     var handlers = wccr.getContentHandlers(TYPE_MAYBE_FEED, {});
     if (handlers.length != 0) {
-      var ios = Cc["@mozilla.org/network/io-service;1"].
-                getService(Ci.nsIIOService);
       for (var i = 0; i < handlers.length; ++i) {
         menuItem = this._document.createElementNS(XUL_NS, "menuitem");
         menuItem.className = "menuitem-iconic";
@@ -597,15 +609,17 @@ FeedWriter.prototype = {
         menuItem.setAttribute("handlerType", "web");
         menuItem.setAttribute("webhandlerurl", handlers[i].uri);
 
-        var uri = ios.newURI(handlers[i].uri, null, null);
-        menuItem.setAttribute("src", uri.prePath + "/favicon.ico");
-
         // a11y
         menuItem.setAttribute("title", handlers[i].name);
         menuItem.setAttributeNS("http://www.w3.org/TR/xhtml2",
                                 "role", "wairole:listitem");
-
         handlersMenuPopup.appendChild(menuItem);
+
+        // For privacy reasons we cannot set the image attribute directly
+        // to the icon url, see Bug 358878
+        var uri = makeURI(handlers[i].uri);
+        if (uri) 
+          new iconDataURIGenerator(uri.prePath + "/favicon.ico", menuItem)
       }
     }
 
@@ -779,7 +793,7 @@ FeedWriter.prototype = {
           prefs.setComplexValue(PREF_SELECTED_APP, Ci.nsILocalFile, 
                                 this.selectedApplicationItemWrapped.file);
           break;
-//@line 916 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
+//@line 930 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/FeedWriter.js"
         case "liveBookmarksMenuItem":
           defaultHandler = "bookmarks";
           prefs.setCharPref(PREF_SELECTED_READER, "bookmarks");
@@ -858,6 +872,147 @@ FeedWriter.prototype = {
   }
 };
 
+
+// copied over from nsSearchService.js
+function b64(aBytes) {
+  const B64_CHARS =
+            "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+  var out = "", bits, i, j;
+
+  while (aBytes.length >= 3) {
+    bits = 0;
+    for (i = 0; i < 3; i++) {
+      bits <<= 8;
+      bits |= aBytes[i];
+    }
+    for (j = 18; j >= 0; j -= 6)
+      out += B64_CHARS[(bits>>j) & 0x3F];
+
+    aBytes.splice(0, 3);
+  }
+
+  switch (aBytes.length) {
+    case 2:
+      out += B64_CHARS[(aBytes[0]>>2) & 0x3F];
+      out += B64_CHARS[((aBytes[0] & 0x03) << 4) | ((aBytes[1] >> 4) & 0x0F)];
+      out += B64_CHARS[((aBytes[1] & 0x0F) << 2)];
+      out += "=";
+      break;
+    case 1:
+      out += B64_CHARS[(aBytes[0]>>2) & 0x3F];
+      out += B64_CHARS[(aBytes[0] & 0x03) << 4];
+      out += "==";
+      break;
+  }
+  return out;
+}
+
+function iconDataURIGenerator(aURISpec, aElement) {
+  var ios = Cc["@mozilla.org/network/io-service;1"].
+            getService(Ci.nsIIOService);
+  var chan = ios.newChannelFromURI(makeURI(aURISpec));
+  chan.notificationCallbacks = this;
+  chan.asyncOpen(this, null);
+
+  this._channel = chan;
+  this._bytes = [];
+  this._element = aElement;
+}
+iconDataURIGenerator.prototype = {
+  _channel: null,
+  _countRead: 0,
+  _stream: null,
+
+  QueryInterface: function FW_IDUG_loadQI(aIID) {
+    if (aIID.equals(Ci.nsISupports)           ||
+        aIID.equals(Ci.nsIRequestObserver)    ||
+        aIID.equals(Ci.nsIStreamListener)     ||
+        aIID.equals(Ci.nsIChannelEventSink)   ||
+        aIID.equals(Ci.nsIInterfaceRequestor) ||
+        aIID.equals(Ci.nsIBadCertListener)    ||
+        // See bug 358878 comment 11
+        aIID.equals(Ci.nsIPrompt)             ||
+        // See FIXME comment below
+        aIID.equals(Ci.nsIHttpEventSink)      ||
+        aIID.equals(Ci.nsIProgressEventSink)  ||
+        false)
+      return this;
+
+    throw Cr.NS_ERROR_NO_INTERFACE;
+  },
+
+  // nsIRequestObserver
+  onStartRequest: function FW_IDUG_loadStartR(aRequest, aContext) {
+    this._stream = Cc["@mozilla.org/binaryinputstream;1"].
+                   createInstance(Ci.nsIBinaryInputStream);
+  },
+
+  onStopRequest: function FW_IDUG_loadStopR(aRequest, aContext, aStatusCode) {
+    var requestFailed = !Components.isSuccessCode(aStatusCode);
+    if (!requestFailed && (aRequest instanceof Ci.nsIHttpChannel))
+      requestFailed = !aRequest.requestSucceeded;
+
+    if (!requestFailed && this._countRead != 0) {
+      try {
+        var dataURI = ICON_DATAURL_PREFIX + b64(this._bytes);
+        this._element.setAttribute("src", dataURI);
+        if (this._element.getAttribute("selected") == "true")
+          this._element.parentNode.parentNode.setAttribute("src", dataURI);
+      }
+      catch(ex) { }
+    }
+    this._channel = null;
+    this._element  = null;
+  },
+
+  // nsIStreamListener
+  onDataAvailable: function FW_IDUG_loadDAvailable(aRequest, aContext,
+                                                   aInputStream, aOffset,
+                                                   aCount) {
+    this._stream.setInputStream(aInputStream);
+
+    // Get a byte array of the data
+    this._bytes = this._bytes.concat(this._stream.readByteArray(aCount));
+    this._countRead += aCount;
+  },
+
+  // nsIChannelEventSink
+  onChannelRedirect: function FW_IDUG_loadCRedirect(aOldChannel, aNewChannel,
+                                                    aFlags) {
+    this._channel = aNewChannel;
+  },
+
+  // nsIInterfaceRequestor
+  getInterface: function FW_IDUG_load_GI(aIID) {
+    return this.QueryInterface(aIID);
+  },
+
+  // nsIBadCertListener
+  confirmUnknownIssuer: function FW_IDUG_load_CUI(aSocketInfo, aCert,
+                                                  aCertAddType) {
+    return false;
+  },
+
+  confirmMismatchDomain: function FW_IDUG_load_CMD(aSocketInfo, aTargetURL,
+                                                   aCert) {
+    return false;
+  },
+
+  confirmCertExpired: function FW_IDUG_load_CCE(aSocketInfo, aCert) {
+    return false;
+  },
+
+  notifyCrlNextupdate: function FW_IDUG_load_NCN(aSocketInfo, aTargetURL, aCert) {
+  },
+
+  // FIXME: bug 253127
+  // nsIHttpEventSink
+  onRedirect: function (aChannel, aNewChannel) { },
+  // nsIProgressEventSink
+  onProgress: function (aRequest, aContext, aProgress, aProgressMax) { },
+  onStatus: function (aRequest, aContext, aStatus, aStatusArg) { }
+};
+
 var Module = {
   QueryInterface: function M_QueryInterface(iid) {
     if (iid.equals(Ci.nsIModule) ||
@@ -903,7 +1058,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 44 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 
 var gTraceOnAssert = true;
 
@@ -928,41 +1083,14 @@ function NS_ASSERT(condition, message) {
   if (condition)
     return;
 
-  var caller = arguments.callee.caller;
   var assertionText = "ASSERT: " + message + "\n";
-  dump(assertionText);
 
-  var stackText = "";
-  if (gTraceOnAssert) {
-    stackText = "Stack Trace: \n";
-    var count = 0;
-    while (caller) {
-      stackText += count++ + ":" + caller.name + "(";
-      for (var i = 0; i < caller.arguments.length; ++i) {
-        var arg = caller.arguments[i];
-        stackText += arg;
-        if (i < caller.arguments.length - 1)
-          stackText += ",";
-      }
-      stackText += ")\n";
-      caller = caller.arguments.callee.caller;
-    }
-  }
-
-  var environment = Components.classes["@mozilla.org/process/environment;1"].
-                    getService(Components.interfaces.nsIEnvironment);
-  if (environment.exists("XUL_ASSERT_PROMPT") &&
-      !parseInt(environment.get("XUL_ASSERT_PROMPT")))
-    return;
-
-  var source = null;
-  if (this.window)
-    source = window;
-  var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
-           getService(Components.interfaces.nsIPromptService);
-  ps.alert(source, "Assertion Failed", assertionText + stackText);
+//@line 72 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+  Components.util.reportError(assertionText);
+  return;
+//@line 108 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
-//@line 37 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/GenericFactory.js"
+//@line 37 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/GenericFactory.js"
 
 /**
  * An object implementing nsIFactory that can construct other objects upon
