@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 38 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -340,7 +340,7 @@ var WebContentConverterRegistrar = {
    */
   registerProtocolHandler: 
   function WCCR_registerProtocolHandler(protocol, uriString, title, contentWindow) {
-//@line 390 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
+//@line 390 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/WebContentConverter.js"
   },
 
   /**
@@ -718,7 +718,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+//@line 44 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 
 var gTraceOnAssert = true;
 
@@ -743,37 +743,10 @@ function NS_ASSERT(condition, message) {
   if (condition)
     return;
 
-  var caller = arguments.callee.caller;
   var assertionText = "ASSERT: " + message + "\n";
-  dump(assertionText);
 
-  var stackText = "";
-  if (gTraceOnAssert) {
-    stackText = "Stack Trace: \n";
-    var count = 0;
-    while (caller) {
-      stackText += count++ + ":" + caller.name + "(";
-      for (var i = 0; i < caller.arguments.length; ++i) {
-        var arg = caller.arguments[i];
-        stackText += arg;
-        if (i < caller.arguments.length - 1)
-          stackText += ",";
-      }
-      stackText += ")\n";
-      caller = caller.arguments.callee.caller;
-    }
-  }
-
-  var environment = Components.classes["@mozilla.org/process/environment;1"].
-                    getService(Components.interfaces.nsIEnvironment);
-  if (environment.exists("XUL_ASSERT_PROMPT") &&
-      !parseInt(environment.get("XUL_ASSERT_PROMPT")))
-    return;
-
-  var source = null;
-  if (this.window)
-    source = window;
-  var ps = Components.classes["@mozilla.org/embedcomp/prompt-service;1"].
-           getService(Components.interfaces.nsIPromptService);
-  ps.alert(source, "Assertion Failed", assertionText + stackText);
+//@line 72 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
+  Components.util.reportError(assertionText);
+  return;
+//@line 108 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/browser/components/feeds/src/../../../../toolkit/content/debug.js"
 }
