@@ -562,15 +562,45 @@ PROT_EnchashDecrypter.prototype.parseRegExps = function(data) {
   return res;
 }
 
-PROT_EnchashDecrypter.prototype.getCanonicalHost = function(str) {
-  var ioservice = Cc["@mozilla.org/network/io-service;1"]
+/**
+ * Get the canonical version of the given URL for lookup in a table of 
+ * type -url.
+ *
+ * @param url String to canonicalize
+ *
+ * @returns String containing the canonicalized url (maximally url-decoded
+ *          with hostname normalized, then specially url-encoded)
+ */
+PROT_EnchashDecrypter.prototype.getCanonicalUrl = function(url) {
+  var escapedUrl = PROT_URLCanonicalizer.canonicalizeURL_(url);
+  // Normalize the host
+  var host = this.getCanonicalHost(escapedUrl);
+  if (!host) {
+    // Probably an invalid url, return what we have so far.
+    return escapedUrl;
+  }
+
+  // Combine our normalized host with our escaped url.
+  var ioService = Cc["@mozilla.org/network/io-service;1"]
+                  .getService(Ci.nsIIOService);
+  var urlObj = ioService.newURI(escapedUrl, null, null);
+  urlObj.host = host;
+  return urlObj.asciiSpec;
+}
+
+/**
+ * @param opt_maxDots Number maximum number of dots to include.
+ */
+PROT_EnchashDecrypter.prototype.getCanonicalHost = function(str, opt_maxDots) {
+  var ioService = Cc["@mozilla.org/network/io-service;1"]
                   .getService(Ci.nsIIOService);
-                  
-  var urlObj = ioservice.newURI(str, null, null);
-  var asciiHost = '';
   try {
-    asciiHost = urlObj.asciiHost;
-  } catch (e) { }
+    var urlObj = ioService.newURI(str, null, null);
+    var asciiHost = urlObj.asciiHost;
+  } catch (e) {
+    G_Debug(this, "Unable to get hostname: " + str);
+    return "";
+  }
 
   var unescaped = this.hexDecode_(asciiHost);
 
@@ -586,19 +616,22 @@ PROT_EnchashDecrypter.prototype.getCanonicalHost = function(str) {
   // ":", "/", ";", and "?"
   var escaped = encodeURI(unescaped);
 
-  var k;
-  var index = escaped.length;
-  for (k = 0; k < PROT_EnchashDecrypter.MAX_DOTS + 1; k++) {
-    temp = escaped.lastIndexOf(".", index - 1);
-    if (temp == -1) {
-      break;
-    } else {
-      index = temp;
+  if (opt_maxDots) {
+    // Limit the number of dots
+    var k;
+    var index = escaped.length;
+    for (k = 0; k < opt_maxDots + 1; k++) {
+      temp = escaped.lastIndexOf(".", index - 1);
+      if (temp == -1) {
+        break;
+      } else {
+        index = temp;
+      }
+    }
+    
+    if (k == opt_maxDots + 1 && index != -1) {
+      escaped = escaped.substring(index + 1);
     }
-  }
-  
-  if (k == PROT_EnchashDecrypter.MAX_DOTS + 1 && index != -1) {
-    escaped = escaped.substring(index + 1);
   }
 
   escaped = escaped.toLowerCase();
@@ -669,9 +702,11 @@ PROT_EnchashDecrypter.prototype.canonicalNum_ = function(num, bytes, octal) {
   if (temp_num == -1) 
     return "";
 
+  // Since we mod the number, we're removing the least significant bits.  We
+  // Want to push them into the front of the array to preserve the order.
   var parts = [];
   while (bytes--) {
-    parts.push("" + (temp_num % 256));
+    parts.unshift("" + (temp_num % 256));
     temp_num -= temp_num % 256;
     temp_num /= 256;
   }
@@ -957,8 +992,10 @@ PROT_URLCanonicalizer.toHex_ = function(val) {
 }
 
 /**
- * Get the canonical version of the given URL for lookup in a table of 
- * type -url.
+ * Canonicalize a URL.  DON'T USE THIS DIRECTLY.  Use
+ * PROT_EnchashDecrypter.prototype.getCanonicalUrl instead.  This method
+ * url-decodes a string, but it doesn't normalize the hostname.  The method
+ * in EnchashDecrypter first calls this method, then normalizes the hostname.
  *
  * @param url String to canonicalize
  *
@@ -1140,6 +1177,7 @@ function UrlClassifierTable() {
   this.debugZone = "urlclassifier-table";
   this.name = '';
   this.needsUpdate = false;
+  this.enchashDecrypter_ = new PROT_EnchashDecrypter();
 }
 
 UrlClassifierTable.prototype.QueryInterface = function(iid) {
@@ -1168,35 +1206,19 @@ UrlClassifierTableUrl.inherits(UrlClassifierTable);
  * Look up a URL in a URL table
  */
 UrlClassifierTableUrl.prototype.exists = function(url, callback) {
-  var canonicalized = PROT_URLCanonicalizer.canonicalizeURL_(url);
-  G_Debug(this, "Looking up: " + url + " (" + canonicalized + ")");
-
-  var dbservice_ = Cc["@mozilla.org/url-classifier/dbservice;1"]
-                   .getService(Ci.nsIUrlClassifierDBService);
-  var callbackHelper = new UrlLookupCallback(callback);
-  dbservice_.exists(this.name,
-                    canonicalized,
-                    BindToObject(callbackHelper.dbCallback,
-                                 callbackHelper));
-}
-
-/**
- * A helper class for handling url lookups in the database.  This allows us to
- * break our reference to callback to avoid memory leaks.
- * @param callback nsIUrlListManagerCallback
- */
-function UrlLookupCallback(callback) {
-  this.callback_ = callback;
-}
-
-/**
- * Callback function from nsIUrlClassifierDBService.exists.  For url lookup,
- * any non-empty string value is a database hit.
- * @param value String
- */
-UrlLookupCallback.prototype.dbCallback = function(value) {
-  this.callback_.handleEvent(value.length > 0);
-  this.callback_ = null;
+  // PROT_URLCanonicalizer.canonicalizeURL_ is the old way of canonicalizing a
+  // URL.  Unfortunately, it doesn't normalize numeric domains so alternate IP
+  // formats (hex, octal, etc) won't trigger a match.
+  // this.enchashDecrypter_.getCanonicalUrl does the right thing and
+  // normalizes a URL to 4 decimal numbers, but the update server may still be
+  // giving us encoded IP addresses.  So to be safe, we check both cases.
+  var oldCanonicalized = PROT_URLCanonicalizer.canonicalizeURL_(url);
+  var canonicalized = this.enchashDecrypter_.getCanonicalUrl(url);
+  G_Debug(this, "Looking up: " + url + " (" + oldCanonicalized + " and " +
+                canonicalized + ")");
+  (new ExistsMultiQuerier([oldCanonicalized, canonicalized],
+                          this.name,
+                          callback)).run();
 }
 
 /////////////////////////////////////////////////////////////////////
@@ -1218,7 +1240,8 @@ UrlClassifierTableDomain.inherits(UrlClassifierTable);
  * @returns Boolean true if the url domain is in the table
  */
 UrlClassifierTableDomain.prototype.exists = function(url, callback) {
-  var urlObj = this.ioService_.newURI(url, null, null);
+  var canonicalized = this.enchashDecrypter_.getCanonicalUrl(url);
+  var urlObj = this.ioService_.newURI(canonicalized, null, null);
   var host = '';
   try {
     host = urlObj.host;
@@ -1261,7 +1284,6 @@ UrlClassifierTableDomain.prototype.exists = function(url, callback) {
 function UrlClassifierTableEnchash() {
   UrlClassifierTable.call(this);
   this.debugZone = "urlclassifier-table-enchash";
-  this.enchashDecrypter_ = new PROT_EnchashDecrypter();
 }
 UrlClassifierTableEnchash.inherits(UrlClassifierTable);
 
@@ -1269,7 +1291,9 @@ UrlClassifierTableEnchash.inherits(UrlClassifierTable);
  * Look up a URL in an enchashDB.  We try all sub domains (up to MAX_DOTS).
  */
 UrlClassifierTableEnchash.prototype.exists = function(url, callback) {
-  var host = this.enchashDecrypter_.getCanonicalHost(url);
+  url = this.enchashDecrypter_.getCanonicalUrl(url);
+  var host = this.enchashDecrypter_.getCanonicalHost(url,
+                                               PROT_EnchashDecrypter.MAX_DOTS);
 
   var possible = [];
   for (var i = 0; i < PROT_EnchashDecrypter.MAX_DOTS + 1; i++) {
@@ -1283,7 +1307,7 @@ UrlClassifierTableEnchash.prototype.exists = function(url, callback) {
   // Run the possible domains against the db.
   (new EnchashMultiQuerier(possible, this.name, callback, url)).run();
 }
-//@line 47 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
+//@line 47 "/builds/tinderbox/Fx-Mozilla1.8-release/Linux_2.4.21-27.0.4.EL_Depend/mozilla/toolkit/components/url-classifier/src/nsUrlClassifierTable.js"
 
 var modScope = this;
 function Init() {
